Index: remoting/protocol/host_message_dispatcher.h |
diff --git a/remoting/protocol/host_message_dispatcher.h b/remoting/protocol/host_message_dispatcher.h |
index 73577234f5fa002da1b766d6e662a9ab94ea1a8b..cd95b264be2d25eeb4cd28d9f9c9efad9f53418f 100644 |
--- a/remoting/protocol/host_message_dispatcher.h |
+++ b/remoting/protocol/host_message_dispatcher.h |
@@ -12,7 +12,6 @@ |
namespace remoting { |
-class ChromotocolConnection; |
class EventMessage; |
class MessageReader; |
@@ -21,14 +20,15 @@ namespace protocol { |
class ControlMessage; |
class HostStub; |
class InputStub; |
+class Session; |
// A message dispatcher used to listen for messages received in |
// ChromotocolConnection. It dispatches messages to the corresponding |
// handler. |
// |
// Internally it contains an EventStreamReader that decodes data on |
// communications channels into protocol buffer messages. |
// EventStreamReader is registered with ChromotocolConnection given to it. |
// |
// Object of this class is owned by ChromotingHost to dispatch messages |
// to itself. |
@@ -42,7 +42,7 @@ class HostMessageDispatcher : |
// Initialize the message dispatcher with the given connection and |
// message handlers. |
// Return true if initalization was successful. |
- bool Initialize(ChromotocolConnection* connection, |
+ bool Initialize(protocol::Session* session, |
HostStub* host_stub, InputStub* input_stub); |
private: |
@@ -21,14 +20,15 @@ namespace protocol { |
// A message dispatcher used to listen for messages received in |
-// ChromotocolConnection. It dispatches messages to the corresponding |
+// protocol::Session. It dispatches messages to the corresponding |
// handler. |
// |
@@ -21,14 +20,15 @@ namespace protocol { |
// Internally it contains an EventStreamReader that decodes data on |
// communications channels into protocol buffer messages. |
-// EventStreamReader is registered with ChromotocolConnection given to it. |
+// EventStreamReader is registered with protocol::Session given to it. |
// |
// Object of this class is owned by ChromotingHost to dispatch messages |